@@ -23,11 +23,14 @@
 #if QT_CONFIG(future)
 #include <QtCore/qfuture.h>
 #endif
+
+QT_BEGIN_NAMESPACE
 class QAbstractHttpServer;
 class QHttpServer;
 class QHttpServerResponse;
 class QHttpServerRouter;
 class QHttpServerRouterRule;
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
@@ -119,7 +122,7 @@ namespace Shiboken
 // PyType functions, to get the PyObjectType for a type T
 template<> inline PyTypeObject *SbkType< ::QAbstractHttpServer >() { return Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]); }
 #if QT_CONFIG(future)
-template<> inline PyTypeObject *SbkType< ::QFutureHttpServerResponse >() { return Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]); }
+template<> inline PyTypeObject *SbkType< QFutureHttpServerResponse >() { return Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QFutureHttpServerResponse_IDX]); }
 #endif
 template<> inline PyTypeObject *SbkType< ::QHttpServer >() { return Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServer_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHttpServerRequest::Method >() { return Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_Method_IDX]); }
