@@ -21,10 +21,13 @@
 #include <QtPrintSupport/qprintengine.h>
 #include <QtPrintSupport/qprinter.h>
 #include <QtPrintSupport/qprintpreviewwidget.h>
+
+QT_BEGIN_NAMESPACE
 class QPageSetupDialog;
 class QPrintDialog;
 class QPrintPreviewDialog;
 class QPrinterInfo;
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
