@@ -20,12 +20,15 @@
 #include <QtStateMachine/qhistorystate.h>
 #include <QtStateMachine/qstate.h>
 #include <QtStateMachine/qstatemachine.h>
+
+QT_BEGIN_NAMESPACE
 class QAbstractState;
 class QEventTransition;
 class QFinalState;
 class QKeyEventTransition;
 class QMouseEventTransition;
 class QSignalTransition;
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
