@@ -16,6 +16,8 @@
 
 // Bound library includes
 #include <QtXml/qdom.h>
+
+QT_BEGIN_NAMESPACE
 class QDomAttr;
 class QDomCDATASection;
 class QDomCharacterData;
@@ -30,6 +32,7 @@ class QDomNodeList;
 class QDomNotation;
 class QDomProcessingInstruction;
 class QDomText;
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
@@ -38,24 +41,25 @@ enum [[deprecated]] : int {
     SBK_QDOMCHARACTERDATA_IDX                                = 4,
     SBK_QDOMCOMMENT_IDX                                      = 6,
     SBK_QDOMDOCUMENT_PARSEOPTION_IDX                         = 10,
-    SBK_QFLAGS_QDOMDOCUMENT_PARSEOPTION_IDX                  = 42,
+    SBK_QFLAGS_QDOMDOCUMENT_PARSEOPTION_IDX                  = 44,
     SBK_QDOMDOCUMENT_IDX                                     = 8,
-    SBK_QDOMDOCUMENTFRAGMENT_IDX                             = 12,
-    SBK_QDOMDOCUMENTTYPE_IDX                                 = 14,
-    SBK_QDOMELEMENT_IDX                                      = 16,
-    SBK_QDOMENTITY_IDX                                       = 18,
-    SBK_QDOMENTITYREFERENCE_IDX                              = 20,
-    SBK_QDOMIMPLEMENTATION_INVALIDDATAPOLICY_IDX             = 24,
-    SBK_QDOMIMPLEMENTATION_IDX                               = 22,
-    SBK_QDOMNAMEDNODEMAP_IDX                                 = 26,
-    SBK_QDOMNODE_NODETYPE_IDX                                = 32,
-    SBK_QDOMNODE_ENCODINGPOLICY_IDX                          = 30,
-    SBK_QDOMNODE_IDX                                         = 28,
-    SBK_QDOMNODELIST_IDX                                     = 34,
-    SBK_QDOMNOTATION_IDX                                     = 36,
-    SBK_QDOMPROCESSINGINSTRUCTION_IDX                        = 38,
-    SBK_QDOMTEXT_IDX                                         = 40,
-    SBK_QTXML_IDX_COUNT                                      = 44,
+    SBK_QDOMDOCUMENT_PARSERESULT_IDX                         = 12,
+    SBK_QDOMDOCUMENTFRAGMENT_IDX                             = 14,
+    SBK_QDOMDOCUMENTTYPE_IDX                                 = 16,
+    SBK_QDOMELEMENT_IDX                                      = 18,
+    SBK_QDOMENTITY_IDX                                       = 20,
+    SBK_QDOMENTITYREFERENCE_IDX                              = 22,
+    SBK_QDOMIMPLEMENTATION_INVALIDDATAPOLICY_IDX             = 26,
+    SBK_QDOMIMPLEMENTATION_IDX                               = 24,
+    SBK_QDOMNAMEDNODEMAP_IDX                                 = 28,
+    SBK_QDOMNODE_NODETYPE_IDX                                = 34,
+    SBK_QDOMNODE_ENCODINGPOLICY_IDX                          = 32,
+    SBK_QDOMNODE_IDX                                         = 30,
+    SBK_QDOMNODELIST_IDX                                     = 36,
+    SBK_QDOMNOTATION_IDX                                     = 38,
+    SBK_QDOMPROCESSINGINSTRUCTION_IDX                        = 40,
+    SBK_QDOMTEXT_IDX                                         = 42,
+    SBK_QTXML_IDX_COUNT                                      = 46,
 };
 
 // Type indices
@@ -65,24 +69,25 @@ enum : int {
     SBK_QDomCharacterData_IDX                                = 2,
     SBK_QDomComment_IDX                                      = 3,
     SBK_QDomDocument_ParseOption_IDX                         = 5,
-    SBK_QFlags_QDomDocument_ParseOption_IDX                  = 21,
+    SBK_QFlags_QDomDocument_ParseOption_IDX                  = 22,
     SBK_QDomDocument_IDX                                     = 4,
-    SBK_QDomDocumentFragment_IDX                             = 6,
-    SBK_QDomDocumentType_IDX                                 = 7,
-    SBK_QDomElement_IDX                                      = 8,
-    SBK_QDomEntity_IDX                                       = 9,
-    SBK_QDomEntityReference_IDX                              = 10,
-    SBK_QDomImplementation_InvalidDataPolicy_IDX             = 12,
-    SBK_QDomImplementation_IDX                               = 11,
-    SBK_QDomNamedNodeMap_IDX                                 = 13,
-    SBK_QDomNode_NodeType_IDX                                = 16,
-    SBK_QDomNode_EncodingPolicy_IDX                          = 15,
-    SBK_QDomNode_IDX                                         = 14,
-    SBK_QDomNodeList_IDX                                     = 17,
-    SBK_QDomNotation_IDX                                     = 18,
-    SBK_QDomProcessingInstruction_IDX                        = 19,
-    SBK_QDomText_IDX                                         = 20,
-    SBK_QtXml_IDX_COUNT                                      = 22,
+    SBK_QDomDocument_ParseResult_IDX                         = 6,
+    SBK_QDomDocumentFragment_IDX                             = 7,
+    SBK_QDomDocumentType_IDX                                 = 8,
+    SBK_QDomElement_IDX                                      = 9,
+    SBK_QDomEntity_IDX                                       = 10,
+    SBK_QDomEntityReference_IDX                              = 11,
+    SBK_QDomImplementation_InvalidDataPolicy_IDX             = 13,
+    SBK_QDomImplementation_IDX                               = 12,
+    SBK_QDomNamedNodeMap_IDX                                 = 14,
+    SBK_QDomNode_NodeType_IDX                                = 17,
+    SBK_QDomNode_EncodingPolicy_IDX                          = 16,
+    SBK_QDomNode_IDX                                         = 15,
+    SBK_QDomNodeList_IDX                                     = 18,
+    SBK_QDomNotation_IDX                                     = 19,
+    SBK_QDomProcessingInstruction_IDX                        = 20,
+    SBK_QDomText_IDX                                         = 21,
+    SBK_QtXml_IDX_COUNT                                      = 23,
 };
 
 // This variable stores all Python types exported by this module.
@@ -126,6 +131,7 @@ template<> inline PyTypeObject *SbkType< ::QDomComment >() { return Shiboken::Mo
 template<> inline PyTypeObject *SbkType< ::QDomDocument::ParseOption >() { return Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_ParseOption_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QFlags<QDomDocument::ParseOption> >() { return Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QFlags_QDomDocument_ParseOption_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QDomDocument >() { return Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QDomDocument::ParseResult >() { return Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_ParseResult_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QDomDocumentFragment >() { return Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentFragment_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QDomDocumentType >() { return Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QDomElement >() { return Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomElement_IDX]); }
